#
# spec file for package gopass
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global make_args PREFIX=%{_prefix} GOPASS_REVISION=v%{version}
Name:           gopass
Version:        1.15.12
Release:        2.2
Summary:        The slightly more awesome standard unix password manager for teams
License:        MIT
URL:            https://www.gopass.pw/
Source:         https://github.com/gopasspw/gopass/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.xz
Source2:        system_config
Source9:        series
Patch0:         do-not-strip.patch
BuildRequires:  golang-packaging
BuildRequires:  golang(API) >= 1.22
BuildRequires:  gpg2
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(bash-completion)
BuildRequires:  zsh
BuildRequires:  fish
Requires:       git-core
%{go_nostrip}

%description
Manage your credentials with ease. In a globally distributed team, on multiple devices or fully offline on an air gapped machine.

Works everywhere - The same user experience on Linux, MacOS, *BSD or Windows
Built for teams - Built from our experience working in distributed development teams
Full autonomy - No network connectivity required, unless you want it

%package bash-completion
Summary:        Bash completion for %{name}
Requires:       %{name} = %{version}
Supplements:    (bash and %{name})
BuildArch:      noarch
Provides:       gopass-completion-bash = %{version}-%{release}
Obsoletes:      gopass-completion-bash < %{version}-%{release}

%description bash-completion
Manage your credentials with ease. In a globally distributed team, on multiple devices or fully offline on an air gapped machine.

Works everywhere - The same user experience on Linux, MacOS, *BSD or Windows
Built for teams - Built from our experience working in distributed development teams
Full autonomy - No network connectivity required, unless you want it

This package holds the shell completion for bash.

%package fish-completion
Summary:        Fish completion for %{name}
Requires:       %{name} = %{version}
Supplements:    (fish and %{name})
BuildArch:      noarch
Provides:       gopass-completion-fish = %{version}-%{release}
Obsoletes:      gopass-completion-fish < %{version}-%{release}

%description fish-completion
Manage your credentials with ease. In a globally distributed team, on multiple devices or fully offline on an air gapped machine.

Works everywhere - The same user experience on Linux, MacOS, *BSD or Windows
Built for teams - Built from our experience working in distributed development teams
Full autonomy - No network connectivity required, unless you want it

This package holds the shell completion for fish.

%package zsh-completion
Summary:        Zsh completion for %{name}
Requires:       %{name} = %{version}
Supplements:    (zsh and %{name})
BuildArch:      noarch
Provides:       gopass-completion-zsh = %{version}-%{release}
Obsoletes:      gopass-completion-zsh < %{version}-%{release}

%description zsh-completion
Manage your credentials with ease. In a globally distributed team, on multiple devices or fully offline on an air gapped machine.

Works everywhere - The same user experience on Linux, MacOS, *BSD or Windows
Built for teams - Built from our experience working in distributed development teams
Full autonomy - No network connectivity required, unless you want it

This package holds the shell completion for zsh.

%package impersonate-pass
Summary:        Provide %{_bindir}/pass as drop-in replacement
Requires:       %{name} = %{version}
Conflicts:      password-store
BuildArch:      noarch

%description impersonate-pass
Manage your credentials with ease. In a globally distributed team, on multiple devices or fully offline on an air gapped machine.

Works everywhere - The same user experience on Linux, MacOS, *BSD or Windows
Built for teams - Built from our experience working in distributed development teams
Full autonomy - No network connectivity required, unless you want it

This package provides a symlink to make this a drop in replacement for password-store.

%prep
%autosetup -p1 -a1

%build
%make_build %{make_args}

%install
%make_install %{make_args}
install -D -m 0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/gopass/config
ln -sf gopass %{buildroot}%{_bindir}/pass

%files
%license LICENSE
%doc *.md
%config(noreplace) %{_sysconfdir}/gopass/
%{_bindir}/gopass
%{_mandir}/man1/gopass.1%{?ext_man}

%files bash-completion
%license LICENSE
%{_datadir}/bash-completion/completions/gopass

%files fish-completion
%license LICENSE
%{_datadir}/fish/vendor_completions.d/gopass.fish

%files zsh-completion
%license LICENSE
%{_datadir}/zsh/site-functions/_gopass

%files impersonate-pass
%license LICENSE
%{_bindir}/pass

%changelog
* Wed Mar 20 2024 Marcus Rueckert <mrueckert@suse.de>
- add the provides/obsoletes for the renamed completion packages
* Wed Mar 20 2024 Marcus Rueckert <mrueckert@suse.de>
- make us ignore the git hash and just use the tag as revision
* Sun Mar 17 2024 Joshua Smith <smolsheep@opensuse.org>
- Fixed completions to be compliant with naming standards.
- Added _service file for maintainers
- Modified the URL as the previous one was resulting in vendoring
  failure
- Update to 1.15.12:
  * bugfix: Use 'en' as default language for the xkcd generator
  * documentation: Fix typo: initilize -> initialize
  * bugfix: Bring back audit summary
  * bugfix: Do not abort saving if the OTP counter is aborted
  * bugfix: Fix NPE when using recipients completion
  * bugfix: Warn if trying to use fscopy inside the store
  * chore: Upgrade to Go 1.22
  * cleanup: Add better logging in case no owner key is found
  * feat: Add .gopass-audit-ignore support to ignore secrets from
    audits
  * feat: Allow supression of password generation in create
    templates
  * ux: Add hint that computing recipients takes some time
  * ux: Do not show create type chooser if only one exists
* Fri Dec  1 2023 Marcus Rueckert <mrueckert@suse.de>
- Update to 1.15.11
  https://github.com/gopasspw/gopass/releases/tag/v1.15.11
* Sun Nov 26 2023 Marcus Rueckert <mrueckert@suse.de>
- Update to 1.15.10
  https://github.com/gopasspw/gopass/releases/tag/v1.15.10
* Sat Nov 18 2023 Marcus Rueckert <mrueckert@suse.de>
- Update to 1.15.9
  https://github.com/gopasspw/gopass/releases/tag/v1.15.9
* Tue Sep 12 2023 Marcus Rueckert <mrueckert@suse.de>
- Update to 1.15.8
  https://github.com/gopasspw/gopass/releases/tag/v1.15.8
* Sat Aug  5 2023 Marcus Rueckert <mrueckert@suse.de>
- restore the series file. it was in the package to allow easily
  setup a working copy for patching.
* Sat Aug  5 2023 Marcus Rueckert <mrueckert@suse.de>
- Update to 1.15.7
  https://github.com/gopasspw/gopass/releases/tag/v1.15.7
* Fri Aug  4 2023 Andreas Stieger <andreas.stieger@gmx.de>
- spec tweaks
* Sun Jul 30 2023 Marcus Rueckert <mrueckert@suse.de>
- Update to 1.15.6
  https://github.com/gopasspw/gopass/releases/tag/v1.15.6
* Sat Apr  8 2023 Marcus Rueckert <mrueckert@suse.de>
- Update to 1.15.5
  https://github.com/gopasspw/gopass/releases/tag/v1.15.5
* Wed Feb 22 2023 Marcus Rueckert <mrueckert@suse.de>
- Added gopass-impersonate-pass for all the people with "pass" in
  their muscle memory.
* Wed Feb 22 2023 Marcus Rueckert <mrueckert@suse.de>
- Require go 1.18 as some modules depend on it
* Wed Feb 22 2023 Marcus Rueckert <mrueckert@suse.de>
- Add /etc/gopass/config to disable the update checker
* Wed Feb 22 2023 Marcus Rueckert <mrueckert@suse.de>
- Update to 1.15.4
  https://github.com/gopasspw/gopass/releases/tag/v1.15.4
* Mon Jan 23 2023 Marcus Rueckert <mrueckert@suse.de>
- initial package
